<?php

namespace Annie\Campaign\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Annie\Campaign\Models\Campaign;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Annie\Campaign\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/campaign/campaign/*')) {
            Route::bind('campaign', function ($campaign) {
                $campaignrepo = $this->app->make('Annie\Campaign\Interfaces\CampaignRepositoryInterface');
                return $campaignrepo->findorNew($campaign);
            });
        }
        if (Request::is('*/campaign/campaign_kind_support/*')) {
            Route::bind('campaign_kind_support', function ($campaign_kind_support) {
                $campaign_kind_supportrepo = $this->app->make('Annie\Campaign\Interfaces\CampaignKindSupportRepositoryInterface');
                return $campaign_kind_supportrepo->findorNew($campaign_kind_support);
            });
        }
        if (Request::is('*/campaign/campaign_volunteer/*')) {
            Route::bind('campaign_volunteer', function ($campaign_volunteer) {
                $campaign_volunteerrepo = $this->app->make('Annie\Campaign\Interfaces\CampaignVolunteerRepositoryInterface');
                return $campaign_volunteerrepo->findorNew($campaign_volunteer);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
